pub struct ListBoundComputer<'a> { /* private fields */ }Expand description
Computes bounds for a query across multiple lists
Precomputes query-related values once, then evaluates bounds per list in O(1).
Implementations
Sourceimpl<'a> ListBoundComputer<'a>
impl<'a> ListBoundComputer<'a>
Sourcepub fn new(query: &'a [f32], metric: DistanceMetric) -> Self
pub fn new(query: &'a [f32], metric: DistanceMetric) -> Self
Create a new bound computer for a query
Sourcepub fn cosine_upper_bound(&self, metadata: &SphericalCapMetadata) -> f32
pub fn cosine_upper_bound(&self, metadata: &SphericalCapMetadata) -> f32
Compute upper bound on similarity for a spherical cap (cosine/dot)
For normalized query q and list with centroid c and max deviation θ_max: max_{v∈L} q·v ≤ cos(max(0, angle(q,c) - θ_max))
Complexity: O(d) for dot product, rest is O(1)
Sourcepub fn l2_lower_bound(&self, metadata: &L2ListMetadata) -> f32
pub fn l2_lower_bound(&self, metadata: &L2ListMetadata) -> f32
Compute lower bound on L2 distance for a list
LB = max(0, dist(q, c) - radius)
Sourcepub fn compute_bound(
&self,
cap: &SphericalCapMetadata,
l2: Option<&L2ListMetadata>,
) -> f32
pub fn compute_bound( &self, cap: &SphericalCapMetadata, l2: Option<&L2ListMetadata>, ) -> f32
Compute bound appropriate for the configured metric
For similarity metrics (cosine, dot): returns upper bound (higher = tighter) For distance metrics (L2): returns lower bound (lower = tighter)