pub struct ErrorEnvelopeSet {
pub envelopes: Vec<ErrorEnvelope>,
pub global: ErrorEnvelope,
}Expand description
Collection of error envelopes for all lists
Fields
envelopes: Vec<ErrorEnvelope>Per-list envelopes
global: ErrorEnvelopeGlobal envelope
Implementations
Sourceimpl ErrorEnvelopeSet
impl ErrorEnvelopeSet
Sourcepub fn get(&self, list_idx: usize) -> &ErrorEnvelope
pub fn get(&self, list_idx: usize) -> &ErrorEnvelope
Get envelope for a list, falling back to global if not available
Sourcepub fn safe_true_threshold(
&self,
list_idx: usize,
proxy: f32,
confidence: f32,
) -> f32
pub fn safe_true_threshold( &self, list_idx: usize, proxy: f32, confidence: f32, ) -> f32
Convert proxy kth to safe true threshold
Sourcepub fn can_terminate(
&self,
kth_proxy: f32,
remaining_list_bounds: &[(usize, f32)],
confidence: f32,
) -> bool
pub fn can_terminate( &self, kth_proxy: f32, remaining_list_bounds: &[(usize, f32)], confidence: f32, ) -> bool
Check if we can terminate: all remaining lists have bounds below kth true threshold
Sourcepub fn from_bytes(bytes: &[u8]) -> Option<Self>
pub fn from_bytes(bytes: &[u8]) -> Option<Self>
Deserialize from bytes