pub struct TombstoneFilter { /* private fields */ }Expand description
Filter for vector search results that excludes deleted IDs
Implementations
Sourceimpl TombstoneFilter
impl TombstoneFilter
Sourcepub fn new(manager: Arc<TombstoneManager>) -> Self
pub fn new(manager: Arc<TombstoneManager>) -> Self
Create a new tombstone filter
Sourcepub fn with_overfetch(self, factor: f32) -> Self
pub fn with_overfetch(self, factor: f32) -> Self
Set the over-fetch factor
Sourcepub fn effective_k(&self, k: usize) -> usize
pub fn effective_k(&self, k: usize) -> usize
Calculate how many candidates to fetch given the target K
Sourcepub fn filter<T>(
&self,
results: Vec<(InternalId, T)>,
limit: usize,
) -> Vec<(InternalId, T)>
pub fn filter<T>( &self, results: Vec<(InternalId, T)>, limit: usize, ) -> Vec<(InternalId, T)>
Filter search results, removing deleted IDs
Sourcepub fn filter_with_continuation<T>(
&self,
results: Vec<(InternalId, T)>,
limit: usize,
) -> (Vec<(InternalId, T)>, bool)
pub fn filter_with_continuation<T>( &self, results: Vec<(InternalId, T)>, limit: usize, ) -> (Vec<(InternalId, T)>, bool)
Filter and check if we need more candidates